@@ -18,6 +18,7 @@ Part of the code was imported from Gaudi and inspired by
 * https://github.com/HEP-SF/tools
 """
 import itertools
+import re
 import sys
 
 from pkg_resources import DistributionNotFound, get_distribution
@@ -163,8 +164,11 @@ def requires(binary_tag):
     Return the minimum required platform for a binary_tag.
     """
     arch, os_id, comp = binary_tag.split("-")[:3]
+    # handling of special conventions
     if comp.startswith(("gcc", "clang")) and arch.startswith("x86_64"):
-        comp_version = comp.strip("gcc").strip("clang").split("+", 1)[0]
+        # extract digits from the compiler id
+        m = re.search(r"\d+", comp)
+        comp_version = m.group(0) if m else "0"
         # Between gcc 3.4 and gcc 6.2, two digits were used for the version
         # Append "0" to all other versions to make the subsequent comparison work
         if not (3 <= int(comp_version[0]) <= 6):
