@@ -9,25 +9,26 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
+from __future__ import absolute_import, division, print_function
 
 import argparse
-from collections import defaultdict
-from distutils.spawn import find_executable
 import json
 import os
 import subprocess
 import sys
+from collections import defaultdict
+from distutils.spawn import find_executable
 
 try:
     from shlex import join as join_cmd
 except ImportError:
+
     def join_cmd(cmd):
         from pipes import quote
+
         return " ".join(quote(c) for c in cmd)
 
+
 try:
     FileNotFoundError
 except NameError:
@@ -124,7 +125,9 @@ def check_cvmfs(results):
             results["required_cvmfs"][path] = os.listdir(path)
         except OSError:
             results["required_cvmfs"][path] = None
-            results["errors"].append("Required CVMFS location " + path + " is not mounted")
+            results["errors"].append(
+                "Required CVMFS location " + path + " is not mounted"
+            )
 
     for path in OPTIONAL_CVMFS_LOCATIONS:
         try:
@@ -143,7 +146,9 @@ def check_singularity(results):
                 "large number (e.g. 15076)"
             )
     except Exception as e:
-        results["errors"].append("Failed to parse /proc/sys/user/max_user_namespaces: %s" % e)
+        results["errors"].append(
+            "Failed to parse /proc/sys/user/max_user_namespaces: %s" % e
+        )
 
     results["singularity"] = find_executable("singularity")
 
@@ -172,7 +177,7 @@ def check_singularity(results):
                 "--siteroot=/cvmfs/lhcb.cern.ch/lib",
                 "DaVinci/v45r5",
                 "gaudirun.py",
-                "--help"
+                "--help",
             ],
         )
 
@@ -193,7 +198,9 @@ def run_cmd(results, command):
     else:
         results["commands"][cmd] = proc.returncode, stdout, stderr
         if proc.returncode > 0:
-            results["errors"].append("Command exited with %d: %s" % (proc.returncode, cmd))
+            results["errors"].append(
+                "Command exited with %d: %s" % (proc.returncode, cmd)
+            )
     return results["commands"][cmd]
 
 
@@ -204,8 +211,8 @@ def run_singularity(results, cmd, silent=False, verbose=False):
     if verbose:
         singularity_cmd_base += ["--verbose"]
     singularity_cmd_base += ["exec", "--bind", "/cvmfs", "--userns"]
-    if 'X509_USER_PROXY' in os.environ:
-        singularity_cmd_base += ['--bind', os.environ['X509_USER_PROXY']]
+    if "X509_USER_PROXY" in os.environ:
+        singularity_cmd_base += ["--bind", os.environ["X509_USER_PROXY"]]
     singularity_cmd_base += ["/cvmfs/cernvm-prod.cern.ch/cvm3"]
     return run_cmd(results, singularity_cmd_base + cmd)
 
