@@ -283,7 +283,8 @@ def singularity_os_ids():
     # If singularity fails to set up the bind mounts it will quietly change the
     # current working directory to be $HOME so fail if the current working
     # directory is not what we expect
-    if os.getcwd() == os.path.normpath(container_dir.strip()):
+    container_dir = os.path.normpath(container_dir.strip())
+    if os.path.realpath(os.getcwd()) == os.path.realpath(container_dir):
         return available_roots
     else:
         return []
